<?php

    use common\modules\fileloader\controllers\FileloaderController;

    return [
    'timeZone' => 'Europe/Kiev',
    'vendorPath' => dirname(dirname(__DIR__)) . '/vendor',
    'controllerMap' => [
        'elfinder' => [
            'class' => 'mihaildev\elfinder\Controller',
            'access' => ['@'], //глобальный доступ к фаил менеджеру @ - для авторизорованных , ? - для гостей , чтоб открыть всем ['@', '?']
            'disabledCommands' => ['netmount'], //отключение ненужных команд https://github.com/Studio-42/elFinder/wiki/Client-configuration-options#commands
            'roots' => [
                [
                    'class' => 'mihaildev\elfinder\volume\UserPath',
                    'path'  => '../../storage/user_{id}',
                    'name'  => 'My Documents'
                ],
            ],
            'watermark' => [
                'source'         => __DIR__.'/logo.png', // Path to Water mark image
                'marginRight'    => 5,          // Margin right pixel
                'marginBottom'   => 5,          // Margin bottom pixel
                'quality'        => 95,         // JPEG image save quality
                'transparency'   => 70,         // Water mark image transparency ( other than PNG )
                'targetType'     => IMG_GIF|IMG_JPG|IMG_PNG|IMG_WBMP, // Target image formats ( bit-field )
                'targetMinPixel' => 200         // Target image minimum pixel size
            ]
        ],
        'artbox-comment' => [
            'class' => \common\modules\comment\Controller::className(),
        ],
        'fileloader' => [
            'class' => FileloaderController::className(),
        ],
    ],

    'modules' => [
        'permit' => [
            'class' => 'common\components\developeruz\db_rbac\Yii2DbRbac',
            'params' => [
                'userClass' => 'common\models\User'
            ]
        ],
        'blog' => [
            'class' => 'common\modules\blog\Module',
        ],
        'file' => [
            'class' => 'common\modules\file\Module',
        ],
        'comment' => [
            'class' => 'common\modules\comment\Module',
            'useRbac' => true,
            'rbac' => [
                'rules' => [
                    \common\modules\comment\rbac\ArtboxCommentCreateRule::className(),
                    \common\modules\comment\rbac\ArtboxCommentDeleteRule::className(),
                    \common\modules\comment\rbac\ArtboxCommentUpdateRule::className(),
                    \common\modules\comment\rbac\ArtboxCommentUpdateOwnRule::className(),
                    \common\modules\comment\rbac\ArtboxCommentDeleteOwnRule::className(),
                ],
                'permissions' => [
                    [
                        'name' => common\modules\comment\Permissions::CREATE,
                        'description' => 'Can create comments',
                        'ruleName' =>(new \common\modules\comment\rbac\ArtboxCommentCreateRule())->name,
                    ],
                    [
                        'name' => common\modules\comment\Permissions::UPDATE,
                        'description' => 'Can update comments',
                        'ruleName' =>(new \common\modules\comment\rbac\ArtboxCommentUpdateRule())->name,
                    ],
                    [
                        'name' => common\modules\comment\Permissions::DELETE,
                        'description' => 'Can delete comments',
                        'ruleName' =>(new \common\modules\comment\rbac\ArtboxCommentDeleteRule())->name,
                    ],
                    [
                        'name' => common\modules\comment\Permissions::UPDATE_OWN,
                        'description' => 'Can update own comments',
                        'ruleName' =>(new \common\modules\comment\rbac\ArtboxCommentUpdateOwnRule())->name,
                    ],
                    [
                        'name' => common\modules\comment\Permissions::DELETE_OWN,
                        'description' => 'Can delete own comments',
                        'ruleName' =>(new \common\modules\comment\rbac\ArtboxCommentDeleteOwnRule())->name,
                    ],
                ],
            ],

        ],

    ],
    'bootstrap' => [
        'options',
    ],
    'components' => [
        'i18n' => [
            'translations' => [
                'frontend' => [
                    'class' => 'yii\i18n\PhpMessageSource',
                    'basePath' => '@frontend/messages',
                    'sourceLanguage' => 'en-US',
                    'fileMap' => [
                        'app'       => 'app.php'
                    ],
                ],
            ],
        ],
        'cache' => [
            'class' => 'yii\caching\FileCache',
        ],
        'formatter' => [
            'booleanFormat' => ['Нет', 'Да'],
            'defaultTimeZone' => 'Europe/Kiev',
        ],
        'urlManager' => [
            'enablePrettyUrl' => true,
            'showScriptName' => false,
            'class'=> 'common\components\LangUrlManager',
            'rules'=>[
                '<module:\w+>/<controller:\w+>/<action:(\w|-)+>' => '<module>/<controller>/<action>',
                '<module:\w+>/<controller:\w+>/<action:(\w|-)+>/<id:\d+>' => '<module>/<controller>/<action>',
            ],
        ],

//        'i18n' => [
//            'translations' => [
//                '*' => [
//                    'class' => 'yii\i18n\PhpMessageSource',
//                    'basePath' => '@common/translation',
//                    'fileMap' => [
//                        'app' => 'app.php',
//                        'app/error' => 'error.php',
//                    ],
//                ],
//                'app' => [
//                    'class' => 'yii\i18n\PhpMessageSource',
//                    'basePath' => '@common/translation',
//                    'fileMap' => [
//                        'app' => 'app.php',
//                        'app/error' => 'error.php',
//                    ],
//                ]
//            ],
//        ],
        'authManager' => [
            'class' => 'yii\rbac\DbManager',
            'defaultRoles' => ['USER'],
        ],

        //подключаем конфигурации API соц сетей для авторизации

        'eauth' => [
            'class' => 'nodge\eauth\EAuth',
            'popup' => true, // Use the popup window instead of redirecting.
            'cache' => false, // Cache component name or false to disable cache. Defaults to 'cache' on production environments.
            'cacheExpire' => 0, // Cache lifetime. Defaults to 0 - means unlimited.
            'httpClient' => [
                // uncomment this to use streams in safe_mode
                //'useStreamsFallback' => true,
            ],
            'services' => [ // You can change the providers and their classes.
                'google' => [
                    // register your app here: https://code.google.com/apis/console/
                    'class' => 'nodge\eauth\services\GoogleOAuth2Service',
                    'clientId' => 'artbox-1138',
                    'clientSecret' => '',
                    'title' => 'Google',
                ],
                'twitter' => [
                    // register your app here: https://dev.twitter.com/apps/new
                    'class' => 'nodge\eauth\services\TwitterOAuth1Service',
                    'key' => '8vReLxI63vTs98MBMqhvrszwy',
                    'secret' => 'jOqNbHIkQw4cVKKJkgrMtaEeCcfbeT1GTik4pF6O9D7AmqcwOG',
                ],
                'yandex' => [
                    // register your app here: https://oauth.yandex.ru/client/my
                    'class' => 'nodge\eauth\services\YandexOAuth2Service',
                    'clientId' => 'ea13195ac0424ff8a190838bec41bb71',
                    'clientSecret' => '911f2c9afcbf4f5f9319b3134c096c86',
                    'title' => 'Yandex',
                ],
                'facebook' => [
                    // register your app here: https://developers.facebook.com/apps/
                    'class' => 'nodge\eauth\services\FacebookOAuth2Service',
                    'clientId' => '1642047622727997',
                    'clientSecret' => 'f5b7ba4f062a568678b764fc74cc416e',
                ],
                'yahoo' => [
                    'class' => 'nodge\eauth\services\YahooOpenIDService',
                    //'realm' => '*.example.org', // your domain, can be with wildcard to authenticate on subdomains.
                ],
                'linkedin' => [
                    // register your app here: https://www.linkedin.com/secure/developer
                    'class' => 'nodge\eauth\services\LinkedinOAuth1Service',
                    'key' => '77s41eixn3dyvo',
                    'secret' => '1xLZQ7RRK6RNjo4U',
                    'title' => 'LinkedIn (OAuth1)',
                ],
                'linkedin_oauth2' => [
                    // register your app here: https://www.linkedin.com/secure/developer
                    'class' => 'nodge\eauth\services\LinkedinOAuth2Service',
                    'clientId' => '77s41eixn3dyvo',
                    'clientSecret' => '1xLZQ7RRK6RNjo4U',
                    'title' => 'LinkedIn (OAuth2)',
                ],
                'github' => [
                    // register your app here: https://github.com/settings/applications
                    'class' => 'nodge\eauth\services\GitHubOAuth2Service',
                    'clientId' => 'd00283b5cfb225cd1600',
                    'clientSecret' => 'f482361fad7184819d452f421c8b09db60830b42',
                ],
                'live' => [
                    // register your app here: https://account.live.com/developers/applications/index
                    'class' => 'nodge\eauth\services\LiveOAuth2Service',
                    'clientId' => '00000000481796AE',
                    'clientSecret' => 'rt9GiJrlKz3sE6CvdOeuwWyYbl1tQT03',
                ],
                'steam' => [
                    'class' => 'nodge\eauth\services\SteamOpenIDService',
                    //'realm' => '*.example.org', // your domain, can be with wildcard to authenticate on subdomains.
                ],
                'instagram' => [
                    // register your app here: https://instagram.com/developer/register/
                    'class' => 'nodge\eauth\services\InstagramOAuth2Service',
                    'clientId' => '...',
                    'clientSecret' => '...',
                ],
                'vkontakte' => [
                    // register your app here: https://vk.com/editapp?act=create&site=1
                    'class' => 'nodge\eauth\services\VKontakteOAuth2Service',
                    'clientId' => '5155388',
                    'clientSecret' => 'jxgmdGVQw7huGKRpnX3a',
                ],
                'mailru' => [
                    // register your app here: http://api.mail.ru/sites/my/add
                    'class' => 'nodge\eauth\services\MailruOAuth2Service',
                    'clientId' => '739322',
                    'clientSecret' => 'd6ce7be6ff791375adff58fe0e4460b2',
                ],
                'odnoklassniki' => [
                    // register your app here: http://dev.odnoklassniki.ru/wiki/pages/viewpage.action?pageId=13992188
                    // ... or here: http://www.odnoklassniki.ru/dk?st.cmd=appsInfoMyDevList&st._aid=Apps_Info_MyDev
                    'class' => 'nodge\eauth\services\OdnoklassnikiOAuth2Service',
                    'clientId' => '...',
                    'clientSecret' => '...',
                    'clientPublic' => '...',
                    'title' => 'Odnoklas.',
                ],
            ],
        ],

        // (optionally) you can configure logging
        'log' => [
            'targets' => [
                [
                    'class' => 'yii\log\FileTarget',
                    'logFile' => '@app/runtime/logs/eauth.log',
                    'categories' => ['nodge\eauth\*'],
                    'logVars' => [],
                ],
            ],
        ],

        /*========End=======
         *end api sicial
         *  */
        'options' => [
            'class' => 'common\models\OptionHelper',
        ]
    ],
    'language' => 'ru-RU'
];
