<?php

namespace common\models;

use Yii;
use yii\behaviors\TimestampBehavior;

/**
 * This is the model class for table "feedback_company".
 *
 * @property integer $feedback_company_id
 * @property integer $date_add
 * @property string $name
 * @property string $phone
 * @property string $ip
 * @property integer $user_id
 * @property integer $status
 *
 * @property User $user
 */
class FeedbackCompany extends \yii\db\ActiveRecord
{

    const STATUS_NEW = 1;
    const STATUS_READ = 2;
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'feedback_company';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['name', 'phone', 'user_id'], 'required'],
            [['user_id'], 'integer'],
            [['name', 'phone'], 'string', 'max' => 255],
            [['phone'], 'match', 'pattern' => '/^\+?(?:\d{0,3})?[\(\s]?\d{0,5}[\)\s]?\d{3}[-\s]?\d{2}[-\s]?\d{2}$/'],
            [['user_id'], 'exist', 'skipOnError' => true, 'targetClass' => User::className(), 'targetAttribute' => ['user_id' => 'id'], 'filter' => ['type' => 2]],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'feedback_company_id' => 'Feedback Company ID',
            'date_add' => Yii::t('app', 'Feedback date add'),
            'name' => Yii::t('app', 'Feedback name'),
            'phone' => Yii::t('app', 'Feedback phone'),
            'ip' => 'Ip',
            'user_id' => 'User ID',
            'status' => Yii::t('app', 'status'),
        ];
    }

    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            [
                'class'              => TimestampBehavior::className(),
                'createdAtAttribute' => 'date_add',
                'updatedAtAttribute' => false,
            ],
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getUser()
    {
        return $this->hasOne(User::className(), ['id' => 'user_id']);
    }
}
