<?php

    namespace common\models;

    use Yii;
    use yii\behaviors\BlameableBehavior;
    use yii\behaviors\TimestampBehavior;
    use yii\db\Expression;

    /**
     * This is the model class for table "gallery".
     * @property integer $gallery_id
     * @property integer $user_id
     * @property string  $name
     * @property string  $date_add
     * @property integer $user_add_id
     * @property string  $cover
     * @property integer $type
     * @property string  $photo
     * @method string minImg(string $dir, $width, $height = NULL) Resizes image
     * @method array ShowGallery(string $array) Splits string to image paths array
     */
    class Gallery extends \yii\db\ActiveRecord
    {

        /**
         * @inheritdoc
         */
        public static function tableName()
        {
            return 'gallery';
        }

        /**
         * @inheritdoc
         */
        public function behaviors()
        {
            return [
                [
                    'class'              => BlameableBehavior::className(),
                    'createdByAttribute' => 'user_id',
                    'updatedByAttribute' => false,
                ],
                [
                    'class'              => TimestampBehavior::className(),
                    'createdAtAttribute' => 'date_add',
                    'updatedAtAttribute' => false,
                    'value'              => new Expression('NOW()'),
                ],
                [
                    'class'              => 'common\behaviors\ShowImage',
                ],
            ];
        }

        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [ 'name', 'cover' ],
                    'required',
                ],
                [
                    [ 'type' ],
                    'integer',
                ],
                [
                    [ 'photo' ],
                    'string',
                ],
                [
                    [
                        'name',
                        'cover',
                    ],
                    'string',
                    'max' => 255,
                ],
            ];
        }

        /**
         * @inheritdoc
         */
        public function attributeLabels()
        {
            return [
                'gallery_id'  => Yii::t('app', 'gallery_id'),
                'user_id'     => Yii::t('app', 'user_id'),
                'name'        => Yii::t('app', 'name'),
                'date_add'    => Yii::t('app', 'date_add'),
                'user_add_id' => Yii::t('app', 'user_add_id'),
                'cover'       => Yii::t('app', 'cover_g'),
                'type'        => Yii::t('app', 'type_g'),
                'photo'       => Yii::t('app', 'photo_g'),
            ];
        }
    }
