<?php

namespace common\models;

use Yii;


/**
 * This is the model class for table "message".
 *
 * @property integer $message_id
 * @property integer $chat_id
 * @property integer $user_id
 * @property integer $status
 * @property string $text
 * @property string $files
 * @property string $date
 *
 * @property Chat $chat
 */
class Message extends \yii\db\ActiveRecord
{

    public $file;

    const NEW_MESSAGE = 1;
    const READ_MESSAGE = 0;

    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'message';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['chat_id', 'user_id', 'status'], 'integer'],
            [['text'], 'string'],
            [['date','file'], 'safe'],
            [['status'], 'default', 'value' => self::NEW_MESSAGE],
            [['files'], 'string', 'max' => 255],
            [['chat_id'], 'exist', 'skipOnError' => true, 'targetClass' => Chat::className(), 'targetAttribute' => ['chat_id' => 'chat_id']],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'message_id' => Yii::t('app', 'message_id'),
            'chat_id' => Yii::t('app', 'chat_id'),
            'user_id' => Yii::t('app', 'user_id'),
            'status' => Yii::t('app', 'status'),
            'text' => Yii::t('app', 'text'),
            'files' => Yii::t('app', 'files'),
            'date' => Yii::t('app', 'date'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getChat()
    {
        return $this->hasOne(Chat::className(), ['chat_id' => 'chat_id']);
    }

    public function getUser()
    {
        return $this->hasOne(UserInfo::className(), ['user_id' => 'user_id']);
    }

    public function getFilesList(){
        $files = json_decode($this->files);
        if(!empty($files)){
            return File::findAll($files);
        } else {
            return false;
        }


    }

    public function isMy(){
        if($this->user_id == \Yii::$app->user->id){
            return true;
        } else {
            return false;
        }
    }
}
