<?php

    namespace common\models;

    use Yii;
    use yii\base\Model;
    use yii\data\ActiveDataProvider;
    use common\models\Portfolio;

    /**
     * PortfolioSearch represents the model behind the search form about `common\models\Portfolio`.
     */
    class PortfolioSearch extends Portfolio
    {

        public $date_add_from;
        public $date_add_to;
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [
                        'portfolio_id',
                        'user_add_id',
                        'view_count',
                        'gallery_id',
                    ],
                    'integer',
                ],
                [
                    [
                        'name',
                        'link',
                        'date_add',
                        'city',
                        'street',
                        'house',
                        'description',
                        'cover',
                        'specializationString',
                        'date_add_from',
                        'date_add_to',
                    ],
                    'safe',
                ],
                [
                    [
                        'date_add_from',
                    ],
                    'default',
                    'value' => date('Y-m-d', 0),
                ],
                [
                    [
                        'date_add_to',
                    ],
                    'default',
                    'value' => date('Y-m-d'),
                ],
            ];
        }

        /**
         * @inheritdoc
         */
        public function scenarios()
        {
            // bypass scenarios() implementation in the parent class
            return Model::scenarios();
        }

        /**
         * Creates data provider instance with search query applied
         *
         * @param array $params
         *
         * @return ActiveDataProvider
         */
        public function search($params)
        {
            $query = Portfolio::find();

            // add conditions that should always apply here

            $dataProvider = new ActiveDataProvider([
                'query' => $query,
            ]);

            $this->load($params);

            if(!$this->validate()) {
                // uncomment the following line if you do not want to return any records when validation fails
                // $query->where('0=1');
                return $dataProvider;
            }

            $query2 = [ ];
            if(!empty( $this->specializationString )) {
                $query2 = Portfolio::find()
                                 ->select([ 'portfolio.portfolio_id' ], 'DISTINCT')
                                 ->joinWith([ 'specializations' ])
                                 ->where([
                                     'like',
                                     'LOWER(specialization_name)',
                                     mb_strtolower($this->specializationString),
                                 ])
                                 ->asArray()
                                 ->column();
            }

            $query->andWhere([ 'user_id' => \Yii::$app->user->getId() ]);

            // grid filtering conditions
            $query->andFilterWhere([
                'portfolio_id' => $this->portfolio_id,
                'date_add'     => $this->date_add,
                'user_add_id'  => $this->user_add_id,
                'view_count'   => $this->view_count,
                'gallery_id'   => $this->gallery_id,
            ]);

            $query->andFilterWhere([
                'between',
                'date_add',
                $this->date_add_from,
                (new \DateTime($this->date_add_to))->modify('+1 day')->format('Y-m-d')
            ]);

            if(!empty($this->specializationString)) {
                $query->andWhere(
                    [
                        'portfolio_id' => $query2,
                    ]
                );
            }

            $query->andFilterWhere([
                'like',
                'name',
                $this->name,
            ])
                  ->andFilterWhere([
                      'like',
                      'link',
                      $this->link,
                  ])
                  ->andFilterWhere([
                      'like',
                      'city',
                      $this->city,
                  ])
                  ->andFilterWhere([
                      'like',
                      'street',
                      $this->street,
                  ])
                  ->andFilterWhere([
                      'like',
                      'house',
                      $this->house,
                  ])
                  ->andFilterWhere([
                      'like',
                      'description',
                      $this->description,
                  ])
                  ->andFilterWhere([
                      'like',
                      'cover',
                      $this->cover,
                  ]);

            return $dataProvider;
        }
    }
