<?php
    namespace frontend\controllers;

    use common\models\Blog;
    use common\models\BlogSearch;
    use common\models\CompanyInfo;
    use common\models\Country;
    use common\models\Currency;
    use common\models\Department;
    use common\models\Employment;
    use common\models\FeedbackCompany;
    use common\models\FeedbackCompanySearch;
    use common\models\Fields;
    use common\models\File;
    use common\models\Gallery;
    use common\models\GallerySearch;
    use common\models\Job;
    use common\models\Language;
    use common\models\Payment;
    use common\models\Portfolio;
    use common\models\PortfolioSearch;
    use common\models\PortfolioSpecialization;
    use common\models\PortfolioUser;
    use common\models\PortfolioUserSearch;
    use common\models\Project;
    use common\models\ProjectSearch;
    use common\models\Specialization;
    use common\models\Team;
    use common\models\TeamSearch;
    use common\models\UserPayment;
    use common\models\UserSpecialization;
    use common\models\Vacancy;
    use common\models\VacancySearch;
    use Yii;
    use common\models\User;
    use common\models\UserInfo;

    use yii\base\ErrorException;
    use yii\data\Sort;
    use yii\db\ActiveRecord;
    use yii\filters\AccessControl;
    use yii\filters\VerbFilter;
    use yii\web\Controller;
    use yii\web\NotFoundHttpException;
    use yii\web\Response;
    use yii\web\UploadedFile;

    /**
     * Site controller
     */
    class AccountsController extends Controller
    {

        public $layout = 'admin';

        public $defaultAction = 'general';

        public function behaviors()
        {
            return [
                'access' => [
                    'class' => AccessControl::className(),
                    'rules' => [
                        [
                            'allow' => true,
                            'roles' => [ '@' ],
                        ],
                    ],
                ],
                'verbs'  => [
                    'class'   => VerbFilter::className(),
                    'actions' => [
                        'team-delete'      => [ 'POST' ],
                        'vacancy-delete'   => [ 'POST' ],
                        'portfolio-delete' => [ 'POST' ],
                        'projects-delete'  => [ 'POST' ],
                        'blog-delete'      => [ 'POST' ],
                        'gallery-cover'    => [ 'POST' ],
                        'feedback-delete'  => [ 'POST' ],
                        'feedback-read'    => [ 'POST' ],
                    ],
                ],
            ];
        }

        public function beforeAction($action)
        {
            $portfolio_user_count = PortfolioUser::find()
                                                 ->where([
                                                     'user_id' => \Yii::$app->user->id,
                                                     'status'  => 2,
                                                 ])
                                                 ->count();
            $feedback_company_count = FeedbackCompany::find()
                                                     ->where([
                                                         'user_id' => \Yii::$app->user->id,
                                                         'status'  => FeedbackCompany::STATUS_NEW,
                                                     ])
                                                     ->count();
            $this->view->params[ 'portfolio_user_count' ] = $portfolio_user_count;
            $this->view->params[ 'feedback_company_count' ] = $feedback_company_count;
            return parent::beforeAction($action); // TODO: Change the autogenerated stub
        }

        /**
         * Page of additional skills, consist:
         * * working with programs;
         * * education;
         * * own developments and patents;
         * * courses and trainings;
         * @return string
         */
        public function actionAddSkills()
        {
            $user = \Yii::$app->user->identity;
            if(!empty( \Yii::$app->request->post() )) {
                Fields::saveFieldData(Yii::$app->request->post('Fields'), \Yii::$app->user->identity->id, User::className(), 'ru');
            }
            return $this->render('add-skills', [ 'user' => $user ]);
        }

        /**
         * Page of blog grid view
         * @return string
         */
        public function actionBlog()
        {
            $searchModel = new BlogSearch();
            $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

            return $this->render('blog', [
                'searchModel'  => $searchModel,
                'dataProvider' => $dataProvider,
            ]);
        }

        /**
         * Page of creating one record of blog.
         * @return string|\yii\web\Response Page html / Redirect
         */
        public function actionBlogCreate()
        {
            $blog = new Blog();
            $post = \Yii::$app->request->post();
            if($blog->load($post) && $blog->save()) {
                return $this->redirect([
                    'blog',
                ]);
            } else {
                return $this->render('_blog_form', [ 'blog' => $blog ]);
            }
        }

        /**
         * Page of editting one User's record of blog.
         *
         * @param integer $id ID of User's record
         *
         * @return string|\yii\web\Response Page html / Redirect
         * @throws NotFoundHttpException if not found or someone else's post
         */
        public function actionBlogUpdate($id)
        {
            $user = \Yii::$app->user->identity;
            $blog = $user->getBlog()
                         ->where([ 'blog_id' => $id ])
                         ->one();
            if(!$blog instanceof ActiveRecord) {
                throw new NotFoundHttpException('Запись не найдена');
            }
            $post = \Yii::$app->request->post();
            if($blog->load($post) && $blog->save()) {
                return $this->redirect('blog');
            } else {
                return $this->render('_blog_form', [ 'blog' => $blog ]);
            }
        }

        /**
         * Delete User's blog record
         *
         * @param $id ID of User's record
         *
         * @return \yii\web\Response Redirect
         * @throws NotFoundHttpException
         */
        public function actionBlogDelete($id)
        {
            $user = \Yii::$app->user->identity;
            $blog = $user->getBlog()
                         ->where([ 'blog_id' => $id ])
                         ->one();
            if(!$blog instanceof ActiveRecord) {
                throw new NotFoundHttpException('Запись не найдена');
            }
            $blog->delete();
            return $this->redirect('blog');
        }

        /**
         * Page of contacts. Consist:
         * * phones;
         * * social pages;
         * * sites;
         * @return string page html
         */
        public function actionContacts()
        {
            $user = \Yii::$app->user->identity;
            $user_info = $user->userInfo;
            if(empty( $user_info )) {
                $user_info = new UserInfo([ 'user_id' => \Yii::$app->user->getId() ]);
            }
            if(!empty( \Yii::$app->request->post() )) {
                if(!empty( Yii::$app->request->post('Fields') )) {

                    Fields::saveFieldData(Yii::$app->request->post('Fields'), \Yii::$app->user->identity->id, User::className(), 'ru');
                }
                $user_info->load(\Yii::$app->request->post());
                $user_info->save();
            }
            return $this->render('contacts', [ 'user_info' => $user_info ]);
        }

        /**
         * Page of description. Consist of information about User.
         * @return string page html
         */
        public function actionDescription()
        {
            $user = \Yii::$app->user->identity;
            $user_info = $user->userInfo;
            if(empty( $user_info )) {
                $user_info = new UserInfo([ 'user_id' => \Yii::$app->user->getId() ]);
            }
            $post = \Yii::$app->request->post();
            if(!empty( $post )) {
                $user_info->load($post);
                $user_info->save();
            }
            return $this->render('description', [ 'user_info' => $user_info ]);
        }

        /**
         * Page of seniority. Consist:
         * * current job;
         * * year of the beginning of designing
         * * previous jobs
         * @return string page html
         */
        public function actionEmployment()
        {
            $user = \Yii::$app->user->identity;
            $user_info = $user->userInfo;
            if(empty( $user_info )) {
                $user_info = new UserInfo([ 'user_id' => \Yii::$app->user->getId() ]);
            }
            $post = \Yii::$app->request->post();
            if(!empty( $post )) {
                $user_info->load($post);
                $user_info->save();
                $job = [ ];
                foreach($post[ 'Job' ] as $index => $value) {
                    $job[ $index ] = new Job([
                        'user_id' => \Yii::$app->user->getId(),
                        'current' => 0,
                    ]);
                }
                if(Job::loadMultiple($job, $post)) {
                    $job[ 0 ]->current = 1;
                    if(Job::validateMultiple($job)) {
                        Job::deleteAll([ 'user_id' => \Yii::$app->user->getId() ]);
                        foreach($job as $onejob) {
                            $onejob->save(false);
                        }
                    }
                }
            } else {
                $job = $user->getJobs()
                            ->orderBy([ 'current' => SORT_DESC ])
                            ->all();
                if(empty( $job )) {
                    $job[] = new Job([
                        'user_id' => \Yii::$app->user->getId(),
                        'current' => 0,
                    ]);
                }
                if(!$job[ 0 ]->current) {
                    array_unshift($job, new Job([
                        'user_id' => \Yii::$app->user->getId(),
                        'current' => 1,
                    ]));
                }
            }
            return $this->render('employment', [
                'job'       => $job,
                'user_info' => $user_info,
            ]);
        }

        /**
         * Page of Company feedback
         * @return string
         */
        public function actionFeedbackCompany()
        {
            $searchModel = new FeedbackCompanySearch();
            $dataProvider = $searchModel->search(Yii::$app->request->queryParams);
            $dataProvider->pagination = [
                'pageSize' => 20,
            ];
            $dataProvider->sort = new Sort([
                'defaultOrder' => [
                    'status'   => SORT_ASC,
                    'date_add' => SORT_DESC,
                ],
            ]);

            return $this->render('feedback-company', [
                'searchModel'  => $searchModel,
                'dataProvider' => $dataProvider,
            ]);
        }

        /**
         * Delete company feedback
         *
         * @param int $id
         *
         * @return Response
         * @throws NotFoundHttpException
         * @throws \Exception
         */
        public function actionFeedbackDelete($id)
        {
            $model = FeedbackCompany::find()
                                    ->where([
                                        'feedback_company_id' => $id,
                                        'user_id'             => \Yii::$app->user->id,
                                    ])
                                    ->one();

            if(empty( $model )) {
                throw new NotFoundHttpException('Заявка не найдена');
            } else {
                $model->delete();
                return $this->redirect([ 'accounts/feedback-company' ]);
            }
        }

        /**
         * Mark feedback as read
         *
         * @param int $id
         *
         * @return Response
         * @throws NotFoundHttpException
         */
        public function actionFeedbackRead($id)
        {
            $model = FeedbackCompany::find()
                                    ->where([
                                        'feedback_company_id' => $id,
                                        'user_id'             => \Yii::$app->user->id,
                                    ])
                                    ->andWhere([
                                        'not',
                                        [ 'status' => FeedbackCompany::STATUS_READ ],
                                    ])
                                    ->one();

            if(empty( $model )) {
                throw new NotFoundHttpException('Заявка не найдена');
            } else {
                $model->status = FeedbackCompany::STATUS_READ;
                $model->save(false);
                return $this->redirect([ 'accounts/feedback-company' ]);
            }
        }

        /**
         * Page of User's image galleries
         * @return string
         */
        public function actionGallery()
        {
            $searchModel = new GallerySearch();
            $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

            return $this->render('gallery', [
                'searchModel'  => $searchModel,
                'dataProvider' => $dataProvider,
            ]);
        }

        /**
         * Page of User's videos
         * @return string
         */
        public function actionGalleryVideo()
        {

            $user = \Yii::$app->user->identity;

            $video = Fields::getData($user->id, Gallery::className(), 'youtube');

            if(!empty( Yii::$app->request->post('Fields') )) {
                Fields::saveFieldVideoData(Yii::$app->request->post('Fields'), $user->id, Gallery::className(), 'ru');
            }

            return $this->render('gallery-video', [
                'video' => $video,
                'user'  => $user,
            ]);
        }

        /**
         * Page of creating a photo gallery
         * @return string|\yii\web\Response
         */
        public function actionGalleryCreate()
        {
            $gallery = new Gallery();
            $user = \Yii::$app->user->identity;
            $post = \Yii::$app->request->post();
            if($gallery->load($post) && $gallery->save()) {
                return $this->redirect([
                    'gallery',
                ]);
            } else {
                return $this->render('_gallery_form', [
                    'gallery' => $gallery,
                    'user'    => $user,
                ]);
            }
        }

        /**
         * Page of updating existing photo gallery
         *
         * @param $id ID of Gallery
         *
         * @return string|\yii\web\Response
         */
        public function actionGalleryUpdate($id)
        {
            $user = \Yii::$app->user->identity;
            $gallery = $user->getGalleries()
                            ->where([ 'gallery_id' => $id ])
                            ->one();
            $post = \Yii::$app->request->post();
            if($gallery->load($post) && $gallery->save()) {
                return $this->redirect([
                    'gallery',
                ]);
            } else {
                return $this->render('_gallery_form', [
                    'gallery' => $gallery,
                    'user'    => $user,
                ]);
            }
        }

        /**
         * Page of deleting existing photo gallery
         *
         * @param $id ID of Gallery
         *
         * @throws \Exception
         */
        public function actionGalleryDelete($id)
        {
            Gallery::findOne($id)
                   ->delete();
            $this->redirect('gallery');
        }

        /**
         * Page of credentials. Consist:
         * <ul>
         *      <li>
         *          Company info:
         *          <ul>
         *              <li>Company name</li>
         *              <li>Employees count</li>
         *              <li>Street</li>
         *              <li>House</li>
         *          </ul>
         *      </li>
         *      <li>
         *          User info:
         *          <ul>
         *              <li>User name</li>
         *              <li>User surname</li>
         *              <li>Email</li>
         *          </ul>
         *      </li>
         *      <li>
         *          Common info:
         *          <ul>
         *              <li>Status (free/busy)</li>
         *              <li>City</li>
         *              <li>Avatar</li>
         *              <li>Cover</li>
         *              <li>Membership</li>
         *          </ul>
         *      </li>
         * </ul>
         * @return string page html
         */
        public function actionGeneral()
        {
            /**
             * @var User $user
             */
            $user = \Yii::$app->user->identity;
            $user_info = $user->userInfo;
            $company_info = $user->companyInfo;
            if(empty( $user_info )) {
                //$user_info = new UserInfo([ 'user_id' => $user->id ]);
            }

            if(empty( $company_info )) {
                $company_info = new CompanyInfo([ 'user_id' => $user->id ]);
            }

            $post = \Yii::$app->request->post();
            if(!empty( $post )) {

                if($user_info->load($post)) {
                    $user_info->save();
                }

                if($company_info->load($post)) {
                    $company_info->save();
                }

                if($user->load($post) && $user->save()) {
                    \Yii::$app->session->setFlash('userinfoupdate', 'Информация успешно обновлена');
                } else {
                    \Yii::$app->session->setFlash('userinfoupdate', 'Ошибка обновления. Проверьте форму');
                }
            }
            return $this->render('general', [
                'user_info'    => $user_info,
                'user'         => $user,
                'company_info' => $company_info,
            ]);
        }

        /**
         * Renders form via ajax, using lastindex.
         *
         * @param integer $lastindex Last index of form input of current type
         *
         * @return string
         */
        public function actionGetForm($lastindex)
        {
            return $this->renderAjax('_job_form', [ 'index' => $lastindex + 1 ]);
        }

        public function actionParticipant()
        {
            $searchModel = new PortfolioUserSearch();
            $dataProvider = $searchModel->search(Yii::$app->request->queryParams);
            $dataProvider->query->joinWith('portfolio');
            $dataProvider->sort = new Sort([
                'defaultOrder' => [
                    'portfolio_user_id' => SORT_ASC,
                ],
                'attributes'   => [
                    'project' => [
                        'asc'  => [
                            'portfolio.name' => SORT_ASC,
                        ],
                        'desc' => [
                            'portfolio.name' => SORT_DESC,
                        ],
                    ],
                    'portfolio_user_id',
                    'position',
                    'time',
                    'status',
                ],
            ]);
            $dataProvider->pagination->pageSize = 5;
            return $this->render('participant', [
                'searchModel'  => $searchModel,
                'dataProvider' => $dataProvider,
            ]);
        }

        public function actionParticipantConfirm($id)
        {
            $portfolioUser = PortfolioUser::find()
                                          ->where([
                                              'portfolio_user_id' => $id,
                                              'user_id'           => \Yii::$app->user->id,
                                              'status'            => 2,
                                          ])
                                          ->one();
            if(empty( $portfolioUser )) {
                throw new NotFoundHttpException('Приглашение не найдено');
            }
            $portfolioUser->status = 1;
            if($portfolioUser->save(false)) {
                return $this->redirect([ 'accounts/participant' ]);
            } else {
                throw new \Exception('Неизвестная ошибка');
            }
        }

        public function actionParticipantDelete($id)
        {
            $portfolioUser = PortfolioUser::find()
                                          ->where([
                                              'portfolio_user_id' => $id,
                                              'user_id'           => \Yii::$app->user->id,
                                          ])
                                          ->one();
            if(empty( $portfolioUser )) {
                throw new NotFoundHttpException('Приглашение не найдено');
            }
            if($portfolioUser->delete()) {
                return $this->redirect([ 'accounts/participant' ]);
            } else {
                throw new \Exception('Неизвестная ошибка');
            }
        }

        public function actionParticipantEdit($id)
        {
            $portfolioUser = PortfolioUser::find()
                                          ->where([
                                              'portfolio_user_id' => $id,
                                              'user_id'           => \Yii::$app->user->id,
                                          ])
                                          ->with('gallery')
                                          ->one();
            if(empty( $portfolioUser )) {
                throw new NotFoundHttpException('Приглашение не найдено');
            }
            $post = \Yii::$app->request->post();
            if(!empty( $post )) {
                if($portfolioUser->load($post)) {
                    $portfolioUser->status = 1;
                    if($portfolioUser->save()) {
                        if(!empty( $portfolioUser->gallery )) {
                            $portfolioUser->gallery->load($post);
                            $portfolioUser->portfolioGallery->load($post);
                            if($portfolioUser->gallery->save() && $portfolioUser->portfolioGallery->save()) {
                                return $this->redirect([ 'accounts/participant' ]);
                            }
                        } else {
                            return $this->redirect([
                                'accounts/participant-edit',
                                'id' => $portfolioUser->portfolio_user_id,
                            ]);
                        }
                    }
                }
            }
            return $this->render('participant-edit', [ 'model' => $portfolioUser ]);
        }

        /**
         * Page of User's portfolio
         * @return string
         */
        public function actionPortfolio()
        {
            $searchModel = new PortfolioSearch();
            $dataProvider = $searchModel->search(Yii::$app->request->queryParams);
            $dataProvider->pagination->pageSize = 5;
            $dataProvider->sort->defaultOrder = [ 'portfolio_id' => SORT_ASC ];
            return $this->render('portfolio', [
                'searchModel'  => $searchModel,
                'dataProvider' => $dataProvider,
            ]);
        }

        /**
         * Page of creating User's portfolio records.
         * @return string|\yii\web\Response
         */
        public function actionPortfolioCreate()
        {
            $user = \Yii::$app->user->identity;
            $portfolio = new Portfolio();

            $specializations = Specialization::find()
                                             ->where([ 'specialization_pid' => 0 ])
                                             ->orderBy('specialization_id')
                                             ->all();
            $galleries = $user->getGalleries()
                              ->select([
                                  'name',
                                  'gallery_id',
                              ])
                              ->asArray()
                              ->indexBy('gallery_id')
                              ->column();
            $post = \Yii::$app->request->post();
            $portfolioUsers = $portfolio->portfolioUsers;
            if(!empty( $post )) {
                $portfolio->load($post);
                $portfolio->validate();
                if(!$portfolio->hasErrors()) {
                    $portfolio->save();
                    $portfolio->unlinkAll('specializations', true);
                    foreach($portfolio->specializationInput as $one_specialization) {
                        $portfolio->link('specializations', Specialization::findOne($one_specialization));
                    }
                    $portfolio->unlinkAll('portfolioUsers', true);
                    $success = true;
                    if(!empty( $post[ 'PortfolioUser' ] )) {
                        $portfolioUsers = [ ];
                        foreach($post[ 'PortfolioUser' ] as $index => $item) {
                            $portfolioUsers[ $index ] = new PortfolioUser([ 'portfolio_id' => $portfolio->portfolio_id ]);
                        }
                        $success = ( PortfolioUser::loadMultiple($portfolioUsers, $post) && PortfolioUser::validateMultiple($portfolioUsers) );
                        if($success) {
                            foreach($portfolioUsers as $index => $portfolioUser) {
                                $portfolioUser->save(false);
                            }
                        }
                    }
                    if($success) {
                        return $this->redirect('portfolio');
                    }
                }
            }
            return $this->render('_portfolio_form', [
                'portfolio'       => $portfolio,
                'specializations' => $specializations,
                'galleries'       => $galleries,
                'portfolioUsers'  => $portfolioUsers,
            ]);
        }

        /**
         * Page of updating User's portfolio record.
         *
         * @param integer $id ID of User's portfolio record
         *
         * @return string|\yii\web\Response
         * @throws NotFoundHttpException if record not found
         */
        public function actionPortfolioUpdate($id)
        {
            $user = \Yii::$app->user->identity;
            $portfolio = $user->getPortfolios()
                              ->where([ 'portfolio_id' => $id ])
                              ->with('portfolioUsers.user')
                              ->one();
            $galleries = $user->getGalleries()
                              ->select([
                                  'name',
                                  'gallery_id',
                              ])
                              ->asArray()
                              ->indexBy('gallery_id')
                              ->column();
            if(!$portfolio instanceof ActiveRecord) {
                throw new NotFoundHttpException('Запись не найдена');
            }
            $specializations = Specialization::find()
                                             ->where([ 'specialization_pid' => 0 ])
                                             ->orderBy('specialization_id')
                                             ->all();

            $post = \Yii::$app->request->post();
            $portfolioUsers = $portfolio->getPortfolioUsers()
                                        ->where([ 'status' => 2 ])
                                        ->all();
            $portfolioUsersConfirmed = $portfolio->getPortfolioUsers()
                                                 ->where([ 'status' => 1 ])
                                                 ->indexBy('user_id')
                                                 ->all();

            if(!empty( $post )) {
                $portfolio->load($post);
                $portfolio->validate();
                if(!$portfolio->hasErrors()) {
                    $portfolio->save();
                    $portfolio->unlinkAll('specializations', true);
                    foreach($portfolio->specializationInput as $one_specialization) {
                        $portfolio->link('specializations', Specialization::findOne($one_specialization));
                    }
                    PortfolioUser::deleteAll([
                        'portfolio_id' => $portfolio->portfolio_id,
                        'status'       => 2,
                    ]);
                    $success = true;
                    if(!empty( $post[ 'PortfolioUser' ] )) {
                        $portfolioUsers = [ ];
                        foreach($post[ 'PortfolioUser' ] as $index => $item) {
                            $portfolioUsers[ $index ] = new PortfolioUser([ 'portfolio_id' => $portfolio->portfolio_id ]);
                        }
                        $success = PortfolioUser::loadMultiple($portfolioUsers, $post);
                        foreach($portfolioUsers as $index => $portfolioUser) {
                            if($portfolioUser->status == 1) {
                                $portfolioUsersConfirmed[ $portfolioUser->user_id ]->position = $portfolioUser->position;
                                $portfolioUsersConfirmed[ $portfolioUser->user_id ]->time = $portfolioUser->time;
                                unset( $portfolioUsers[ $index ] );
                            }
                        }
                        $success = ( $success && PortfolioUser::validateMultiple($portfolioUsers) && PortfolioUser::validateMultiple($portfolioUsersConfirmed) );
                        if($success) {
                            foreach($portfolioUsers as $index => $portfolioUser) {
                                $portfolioUser->status = 2;
                                $portfolioUser->save(false);
                            }
                            foreach($portfolioUsersConfirmed as $index => $portfolioUserConfirmed) {
                                $portfolioUserConfirmed->save(false);
                            }
                        }
                    }
                    if($success) {
                        return $this->redirect('portfolio');
                    }
                }
            }

            return $this->render('_portfolio_form', [
                'portfolio'               => $portfolio,
                'specializations'         => $specializations,
                'galleries'               => $galleries,
                'portfolioUsers'          => $portfolioUsers,
                'portfolioUsersConfirmed' => $portfolioUsersConfirmed,
            ]);
        }

        /**
         * Page of deleting User's portfolio record.
         *
         * @param integer $id ID of User's portfolio record
         *
         * @throws NotFoundHttpException
         * @throws \Exception if record not found
         */
        public function actionPortfolioDelete($id)
        {
            $user = \Yii::$app->user->identity;
            $portfolio = $user->getPortfolios()
                              ->where([ 'portfolio_id' => $id ])
                              ->one();
            if(!$portfolio instanceof ActiveRecord) {
                throw new NotFoundHttpException('Запись не найдена');
            }
            $portfolio->delete();
            $this->redirect('portfolio');
        }

        /**
         * Page of User's projects.
         * @return string
         */
        public function actionProjects()
        {
            $searchModel = new ProjectSearch();
            $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

            return $this->render('projects', [
                'searchModel'  => $searchModel,
                'dataProvider' => $dataProvider,
            ]);
        }

        /**
         * Page of creating User's project.
         * @return string|\yii\web\Response
         */
        public function actionProjectsCreate()
        {
            $project = new Project();

            $specializations = Specialization::find()
                                             ->where([ 'specialization_pid' => 0 ])
                                             ->orderBy('specialization_id')
                                             ->all();

            $payment = Payment::find()
                              ->select([
                                  'name',
                                  'payment_id',
                              ])
                              ->indexBy('payment_id')
                              ->asArray()
                              ->column();
            $projects = Project::find()
                               ->select([
                                   'name',
                                   'project_id',
                               ])
                               ->where([ 'user_id' => \Yii::$app->user->getId() ])
                               ->indexBy('project_id')
                               ->asArray()
                               ->column();
            $post = \Yii::$app->request->post();
            if(!empty( $post )) {
                $project->load($post);
                $project->files = UploadedFile::getInstances($project, 'files');
                if(!empty( $project->files )) {
                    $file_id = [ ];
                    if(is_array($project->files)) {
                        foreach($project->files as $file) {
                            if($file instanceof UploadedFile) {
                                $file_model = new File();
                                $file_id[] = $file_model->saveFile($file);
                            }
                        }
                    } else {
                        if($project->files instanceof UploadedFile) {
                            $file_model = new File();
                            $file_id[] = $file_model->saveFile($this->file);
                        }
                    }
                    $project->file = json_encode($file_id);
                }
                $project->validate();
                if(!$project->hasErrors()) {
                    $project->save(false);
                    $project->unlinkAll('specializations', true);
                    foreach($project->specializationInput as $one_specialization) {
                        $project->link('specializations', Specialization::findOne($one_specialization));
                    }
                    $project->unlinkAll('payments', true);
                    foreach($project->paymentInput as $one_payment) {
                        $project->link('payments', Payment::findOne($one_payment));
                    }
                    return $this->redirect([
                        'projects',
                    ]);
                }
            }
            return $this->render('_projects_form', [
                'project'         => $project,
                'specializations' => $specializations,
                'payment'         => $payment,
                'projects'        => $projects,
            ]);
        }

        /**
         * Page of updating User's project.
         *
         * @param integer $id ID of User's project
         *
         * @return string
         * @throws NotFoundHttpException if record not found
         */
        public function actionProjectsUpdate($id)
        {
            $user = \Yii::$app->user->identity;
            $project = $user->getProjects()
                            ->where([ 'project_id' => $id ])
                            ->one();
            if(!$project instanceof ActiveRecord) {
                throw new NotFoundHttpException('Запись не найдена');
            }
            $specializations = Specialization::find()
                                             ->where([ 'specialization_pid' => 0 ])
                                             ->orderBy('specialization_id')
                                             ->all();
            $payment = Payment::find()
                              ->select([
                                  'name',
                                  'payment_id',
                              ])
                              ->indexBy('payment_id')
                              ->asArray()
                              ->column();
            $projects = $user->getProjects()
                             ->select([
                                 'name',
                                 'project_id',
                             ])
                             ->andWhere([
                                 'not',
                                 [ 'project_id' => $project->project_id ],
                             ])
                             ->indexBy('project_id')
                             ->asArray()
                             ->column();
            $post = \Yii::$app->request->post();
            if(!empty( $post )) {
                $project->load($post);
                $project->files = UploadedFile::getInstances($project, 'files');
                if(!empty( $project->files )) {
                    $file_id = [ ];
                    if(is_array($project->files)) {
                        foreach($project->files as $file) {
                            if($file instanceof UploadedFile) {
                                $file_model = new File();
                                $file_id[] = $file_model->saveFile($file);
                            }
                        }
                    } else {
                        if($project->files instanceof UploadedFile) {
                            $file_model = new File();
                            $file_id[] = $file_model->saveFile($this->file);
                        }
                    }
                    $project->file = json_encode($file_id);
                }
                $project->validate();
                if(!$project->hasErrors()) {
                    $project->save(false);
                    $project->unlinkAll('specializations', true);
                    foreach($project->specializationInput as $one_specialization) {
                        $project->link('specializations', Specialization::findOne($one_specialization));
                    }
                    $project->unlinkAll('payments', true);
                    foreach($project->paymentInput as $one_payment) {
                        $project->link('payments', Payment::findOne($one_payment));
                    }
                    return $this->redirect([ 'projects' ]);
                }
            }
            return $this->render('_projects_form', [
                'project'         => $project,
                'specializations' => $specializations,
                'payment'         => $payment,
                'projects'        => $projects,
            ]);
        }

        /**
         * Page of deleting User's project
         *
         * @param integer $id ID of User's project
         *
         * @throws NotFoundHttpException
         * @throws \Exception
         */
        public function actionProjectsDelete($id)
        {
            $user = \Yii::$app->user->identity;
            $project = $user->getProjects()
                            ->where([ 'project_id' => $id ])
                            ->one();
            if(!$project instanceof ActiveRecord) {
                throw new NotFoundHttpException('Запись не найдена');
            }
            $project->delete();
            $this->redirect('projects');
        }

        /**
         * Page of editting User's service info. Consist of:
         * * cost of work;
         * * service specializations;
         * * work geography;
         * * work guarantee;
         * * work on contract;
         * * providing estimates;
         * * purchase of materials;
         * * delivery of materials;
         * * minimal prepayment;
         * * payment types;
         * @return string
         */
        public function actionService()
        {
            /**
             * @var User $user
             */
            $user = User::find()->where(['id' => \Yii::$app->user->id])->one();
            $user->setSpecializationInput($user->getSpecializationInput());
            $user_info = $user->userInfo;
            if(empty( $user_info )) {
                $user_info = new UserInfo([ 'user_id' => \Yii::$app->user->getId() ]);
            }
            $specializations = Specialization::find()
                                             ->with('children')
                                             ->where([ 'specialization_pid' => 0 ])
                                             ->orderBy('specialization_id')
                                             ->all();
            $payment = Payment::find()
                              ->select([
                                  'name',
                                  'payment_id',
                              ])
                              ->indexBy('payment_id')
                              ->asArray()
                              ->column();
            $currencies = Currency::getCurrencyDropdown();
            $post = \Yii::$app->request->post();
            if(!empty( $post )) {
                $user_info->load($post);
                $user_info->validate();
                if(!$user_info->hasErrors()) {
                    $user_info->save();
                    $user->load($post);
                    $user->unlinkAll('specializations', true);
                    if(is_array($user->specializationInput)) {
                        foreach($user->specializationInput as $one_specialization) {
                            $user->link('specializations', Specialization::findOne($one_specialization));
                        }
                    }
                    $user->unlinkAll('payments', true);
                    if(is_array($user->paymentInput)) {
                        foreach($user->paymentInput as $one_payment) {
                            $user->link('payments', Payment::findOne($one_payment));
                        }
                    }
                }
            }
            return $this->render('service', [
                'user'            => $user,
                'user_info'       => $user_info,
                'specializations' => $specializations,
                'payment'         => $payment,
                'currencies'      => $currencies,
            ]);
        }

        /**
         * Page of account setting. Consist of:
         * * changing password;
         * @return string
         */
        public function actionSetting()
        {
            $user = \Yii::$app->user->identity;
            $post = \Yii::$app->request->post('User');
            if(!empty( $post )) {
                if(empty( $post[ 'new_password' ] )) {
                    $user->addError('new_password', 'Введите новый пароль');
                } else {
                    $user->new_password = $post[ 'new_password' ];
                }
                if(empty( $post[ 'old_password' ] )) {
                    $user->addError('old_password', 'Введите старый пароль');
                } else {
                    $user->old_password = $post[ 'old_password' ];
                }
                if(empty( $post[ 'password_reply' ] ) || $post[ 'password_reply' ] !== $post[ 'new_password' ]) {
                    $user->addError('password_reply', 'Неправильный повтор пароля');
                } else {
                    $user->password_reply = $post[ 'password_reply' ];
                }
                if(!$user->hasErrors()) {
                    if($user->validatePassword($user->old_password)) {
                        $user->setPassword($user->new_password);
                        $user->generateAuthKey();
                        if($user->save()) {
                            \Yii::$app->session->setFlash('passwordupdate', 'Пароль успешно обновлен');
                        }
                    } else {
                        $user->addError('old_password', 'Неправильный старый пароль');
                    }
                }
            }
            return $this->render('setting', [ 'user' => $user ]);
        }

        /**
         * Page of company's team
         * @return string
         */
        public function actionTeam()
        {
            $searchModel = new TeamSearch();
            $dataProvider = $searchModel->search(Yii::$app->request->queryParams);
            $departments = Department::find()
                                     ->select([
                                         'name',
                                         'department_id',
                                     ])
                                     ->indexBy('department_id')
                                     ->asArray()
                                     ->column();

            return $this->render('team', [
                'searchModel'  => $searchModel,
                'dataProvider' => $dataProvider,
                'departments'  => $departments,
            ]);
        }

        /**
         * Page of creating company's team member
         * @return string|\yii\web\Response
         */
        public function actionTeamCreate()
        {
            $team = new Team();
            $department = Department::find()
                                    ->select([
                                        'name',
                                        'department_id',
                                    ])
                                    ->indexBy('department_id')
                                    ->asArray()
                                    ->column();
            $country = Country::find()
                              ->select([ 'country_name' ])
                              ->indexBy('country_name')
                              ->asArray()
                              ->column();
            $post = \Yii::$app->request->post();
            if($team->load($post) && $team->save()) {
                return $this->redirect([
                    'team',
                ]);
            } else {
                return $this->render('_team_form', [
                    'team'       => $team,
                    'department' => $department,
                    'country'    => $country,
                ]);
            }
        }

        /**
         * Page of updating company's team member info.
         *
         * @param integer $id ID of company's team member
         *
         * @return string|\yii\web\Response
         * @throws NotFoundHttpException
         */
        public function actionTeamUpdate($id)
        {
            $user = \Yii::$app->user->identity;
            $team = $user->getTeams()
                         ->where([ 'team_id' => $id ])
                         ->one();
            if(!$team instanceof ActiveRecord) {
                throw new NotFoundHttpException('Запись не найдена');
            }
            $department = Department::find()
                                    ->select([
                                        'name',
                                        'department_id',
                                    ])
                                    ->indexBy('department_id')
                                    ->asArray()
                                    ->column();
            $country = Country::find()
                              ->select([ 'country_name' ])
                              ->indexBy('country_name')
                              ->asArray()
                              ->column();
            $post = \Yii::$app->request->post();
            if($team->load($post) && $team->save()) {
                return $this->redirect([
                    'team',
                ]);
            } else {
                return $this->render('_team_form', [
                    'team'       => $team,
                    'department' => $department,
                    'country'    => $country,
                ]);
            }
        }

        /**
         * Page of deleting company's team member.
         *
         * @param integer $id ID of company's team member
         *
         * @throws NotFoundHttpException
         * @throws \Exception
         */
        public function actionTeamDelete($id)
        {
            $user = \Yii::$app->user->identity;
            $team = $user->getTeams()
                         ->where([ 'team_id' => $id ])
                         ->one();
            if(!$team instanceof ActiveRecord) {
                throw new NotFoundHttpException('Запись не найдена');

            }
            $team->delete();
            $this->redirect('team');
        }

        /**
         * Page of company's vacancies
         * @return string
         */
        public function actionVacancy()
        {
            $searchModel = new VacancySearch();
            $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

            return $this->render('vacancy', [
                'searchModel'  => $searchModel,
                'dataProvider' => $dataProvider,
            ]);
        }

        /**
         * Page of creating company's vacancies.
         * @return string|\yii\web\Response
         */
        public function actionVacancyCreate()
        {
            $vacancy = new Vacancy();
            $employment = Employment::find()
                                    ->select([
                                        'name',
                                        'employment_id',
                                    ])
                                    ->indexBy('employment_id')
                                    ->asArray()
                                    ->column();
            $specializations = Specialization::find()
                                             ->where([ 'specialization_pid' => 0 ])
                                             ->orderBy('specialization_id')
                                             ->all();
            $currencies = Currency::getCurrencyDropdown();
            $user = \Yii::$app->user->identity;
            $post = \Yii::$app->request->post();
            if(!empty( $post )) {
                $vacancy->load($post);
                $vacancy->validate();
                if(empty( $vacancy->specializationInput )) {
                    $vacancy->addError('specializationInput');
                }
                if(!$vacancy->hasErrors()) {
                    $vacancy->save();
                    Fields::saveFieldData(Yii::$app->request->post('Fields'), $vacancy->vacancy_id, Vacancy::className(), 'ru');
                    $vacancy->unlinkAll('employments', true);
                    foreach($vacancy->employmentInput as $one_employment) {
                        $vacancy->link('employments', Employment::findOne($one_employment));
                    }
                    $vacancy->unlinkAll('specializations', true);
                    foreach($vacancy->specializationInput as $one_specialization) {
                        $vacancy->link('specializations', Specialization::findOne($one_specialization));
                    }
                    return $this->redirect([
                        'vacancy',
                    ]);
                }
            }
            return $this->render('_vacancy_form', [
                'vacancy'         => $vacancy,
                'employment'      => $employment,
                'currencies'      => $currencies,
                'specializations' => $specializations,
                'user'            => $user,
            ]);
        }

        /**
         * Page of updating company's vacancy.
         *
         * @param integer $id ID of company's vacancy.
         *
         * @return string|\yii\web\Response
         * @throws NotFoundHttpException
         */
        public function actionVacancyUpdate($id)
        {
            $user = \Yii::$app->user->identity;
            $vacancy = $user->getVacancies()
                            ->where([ 'vacancy_id' => $id ])
                            ->one();
            if(!$vacancy instanceof ActiveRecord) {
                throw new NotFoundHttpException('Запись не найдена');
            }
            $employment = Employment::find()
                                    ->select([
                                        'name',
                                        'employment_id',
                                    ])
                                    ->indexBy('employment_id')
                                    ->asArray()
                                    ->column();
            $specializations = Specialization::find()
                                             ->where([ 'specialization_pid' => 0 ])
                                             ->orderBy('specialization_id')
                                             ->all();
            $user = \Yii::$app->user->identity;
            $currencies = Currency::getCurrencyDropdown();
            $post = \Yii::$app->request->post();
            if(!empty( $post )) {

                $vacancy->load($post);
                $vacancy->validate();
                if(!$vacancy->hasErrors()) {

                    $vacancy->save();
                    Fields::saveFieldData(Yii::$app->request->post('Fields'), $vacancy->vacancy_id, Vacancy::className(), 'ru');
                    $vacancy->unlinkAll('employments', true);
                    foreach($vacancy->employmentInput as $one_employment) {
                        $vacancy->link('employments', Employment::findOne($one_employment));
                    }
                    $vacancy->unlinkAll('specializations', true);
                    foreach($vacancy->specializationInput as $one_specialization) {
                        $vacancy->link('specializations', Specialization::findOne($one_specialization));
                    }
                    return $this->redirect([
                        'vacancy',
                    ]);
                }
            }
            return $this->render('_vacancy_form', [
                'vacancy'         => $vacancy,
                'employment'      => $employment,
                'currencies'      => $currencies,
                'specializations' => $specializations,
                'user'            => $user,
            ]);
        }

        /**
         * Page of deleting company's vacancy.
         *
         * @param integer $id ID of company's vacancy
         *
         * @throws NotFoundHttpException
         * @throws \Exception
         */
        public function actionVacancyDelete($id)
        {
            $user = \Yii::$app->user->identity;
            $vacancy = $user->getVacancies()
                            ->where([ 'vacancy_id' => $id ])
                            ->one();
            if(!$vacancy instanceof ActiveRecord) {
                throw new NotFoundHttpException('Запись не найдена');

            }
            $vacancy->delete();
            $this->redirect('vacancy');
        }

        /**
         * Used to find model of User and throws exception if not found.
         *
         * @param integer $id ID of User
         *
         * @return User if User with particular ID found
         * @throws NotFoundHttpException if User with particular ID not found
         */
        protected function findUser($id)
        {

            if($model = User::findOne([ "id" => $id ])) {
                return $model;
            } else {
                throw new NotFoundHttpException('The requested page does not exist.');
            }
        }

        public function actionGalleryCover()
        {
            $gallery_id = Yii::$app->request->post('gallery_id');

            $cover = Gallery::find()
                            ->select('cover')
                            ->where([ 'gallery_id' => $gallery_id ])
                            ->column();
            die( $cover[ 0 ] );

        }

    }
