<?php
    /**
     * @var BlogSearch    $searchModel
     * @var ActiveDataProvider $dataProvider
     */
    use common\models\BlogSearch;
    use yii\data\ActiveDataProvider;
    use yii\grid\ActionColumn;
    use yii\grid\GridView;
    use yii\helpers\Html;
    use yii\jui\DatePicker;
    use yii\widgets\ActiveField;

    $this->title = 'Блог';
    $this->params[ 'breadcrumbs' ][] = $this->title;
?>
<div class="login-left-column-title"><?= $this->title ?></div>
<div class="admin-all-pages-add">
    <?= Html::a(Yii::t('app', 'add'), [ 'blog-create' ], [ 'class' => 'btn btn-success' ]) ?>
</div>

<div class="admin-table-portfolio">
    <?= GridView::widget([
        'options' => ['class'=>'style admin-all-pages-wr'],
        'dataProvider' => $dataProvider,
        'filterModel'  => $searchModel,
        'columns'      => [
            [
                'attribute' => 'blog_id',
                'label'     => 'ID',
            ],
            'name',
            [
                'attribute' => 'date_add',
                'filter' => "<div class=\"input-group input-group-xs input-daterange\">
<span class='field-teamsearch-experience_from_from'>".
                    DatePicker::widget([
                        'model' => $searchModel,
                        'attribute' => 'date_add_from',
                        'language' => 'ru',
                        'dateFormat' => 'yyyy-MM-dd',
                        'clientOptions' => [
                            'changeYear' => true,
                            'changeMonth' => true,
                            'yearRange' => "1970:".date('Y'),
                        ],
                    ]).
                    "</span>
<span class=\"input-group-addon kv-field-separator\">
<i class=\"glyphicon glyphicon-resize-horizontal\"></i>
</span>
<span class='field-teamsearch-experience_from_to'>".
                    DatePicker::widget([
                        'model' => $searchModel,
                        'attribute' => 'date_add_to',
                        'language' => 'ru',
                        'dateFormat' => 'yyyy-MM-dd',
                        'clientOptions' => [
                            'changeYear' => true,
                            'changeMonth' => true,
                            'yearRange' => "1970:".date('Y'),
                        ],
                    ])
                    ."</span>"
                    .(($searchModel->hasErrors('date_add_from'))?'Дата начала не может быть больше сегодняшнего дня':'')
                    .(($searchModel->hasErrors('date_add_to'))?'Дата окончания должна быть больше даты начала':'')."
</div>",
                'format' => 'html',
            ],
            'view_count',
            [
                'class'    => ActionColumn::className(),
                'buttons'  => [
                    'update' => function($url, $model, $key) {
                        return Html::a('<img src="/images/ico_pencil.png" alt="">', [
                            'blog-update',
                            'id' => $model->blog_id,
                        ],[
                            'title'        => 'Редактировать',
                        ]);
                    },
                    'delete' => function($url, $model, $key) {
                        return Html::a('<img src="/images/delete-ico.png" alt="">', [
                            'blog-delete',
                            'id' => $model->blog_id,
                        ], [
                            'title'        => Yii::t('app', 'delete'),
                            'aria-label'   => Yii::t('app', 'delete'),
                            'data-confirm' =>  Yii::t('app', 'delete_confirm'),
                            'data-method'  => 'post',
                            'data-pjax'    => '0',
                        ]);
                    },
                ],
                'template' => '{update} {delete}',
            ],
        ],
    ]); ?>
</div>

